==> create-node-react-app-1.0.27.tgz: package/my-app/src/index.tsx <==
import React from 'react'
import ReactDOM from 'react-dom'
import './config/i18next'
import { ApolloProvider } from '@apollo/client'
import { createApolloClient } from './config/createApolloClient'
import providers, { Provide } from 'react-manage-providers'
import { ThemeProvider, CssBaseline, Theme } from '@mui/material'
import theme from './config/createMuiTheme'
import { BrowserRouter as Router, Route, Switch } from 'react-router-dom'
import reportWebVitals from './reportWebVitals'
import App from './App'
import { Home, SignUp } from './pages'

// initialize apollo client
const client = createApolloClient(() => localStorage.getItem('AUTH_TOKEN') || undefined)
providers.push(ApolloProvider, { client })

// initialize MUI theme
const MuiThemeProvider = ({ theme, children }: React.PropsWithChildren<{ theme: Theme }>) => <ThemeProvider theme={theme}>
  <CssBaseline />
  {children}
</ThemeProvider>
providers.push(MuiThemeProvider, { theme })

function AppRoutes() {
  return <Switch>
    <Route path="/signup" component={SignUp} />
    <Route component={Home} />
  </Switch>
}

// Render app
ReactDOM.render(
  <React.StrictMode>
    <Provide>
      <Router>
        <App>
          <AppRoutes />
        </App>
      </Router>
    </Provide>
  </React.StrictMode>,
  document.getElementById('root')
)

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals()

==> create-node-react-app-1.0.29.tgz: package/my-app/src/index.tsx <==
import React from 'react'
import ReactDOM from 'react-dom'
import './config/i18next'
import { ApolloProvider } from '@apollo/client'
import { createApolloClient } from './config/createApolloClient'
import providers, { Provide } from 'react-manage-providers'
import { ThemeProvider, CssBaseline, Theme } from '@mui/material'
import theme from './config/createMuiTheme'
import { BrowserRouter as Router, Route, Switch } from 'react-router-dom'
import reportWebVitals from './reportWebVitals'
import App from './App'
import { Home, SignUp, ResetPassword, Login } from './pages'

// initialize apollo client
const client = createApolloClient(() => localStorage.getItem('AUTH_TOKEN') || undefined)
providers.push(ApolloProvider, { client })

// initialize MUI theme
const MuiThemeProvider = ({ theme, children }: React.PropsWithChildren<{ theme: Theme }>) => <ThemeProvider theme={theme}>
  <CssBaseline />
  {children}
</ThemeProvider>
providers.push(MuiThemeProvider, { theme })

function AppRoutes() {
  return <Switch>
    <Route path="/signup" component={SignUp} />
    <Route path="/reset-password" component={ResetPassword} />
    <Route path="/login" component={Login} />
    <Route component={Home} />
  </Switch>
}

// Render app
ReactDOM.render(
  <React.StrictMode>
    <Provide>
      <Router>
        <App>
          <AppRoutes />
        </App>
      </Router>
    </Provide>
  </React.StrictMode>,
  document.getElementById('root')
)

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals()
